#include "ScriptingDock.hxx"
#include "bindings/Interpreter.hxx"

#include <sstream>

ScriptingDock::ScriptingDock(Interpreter* interpreter, const QString& title, QWidget * parent)
	: QDockWidget(title, parent)
	, logger(log4cxx::Logger::getLogger("ScriptingDock"))
	, interpreter(interpreter) {
	QTabWidget * tab = new QTabWidget;
	QWidget * widget = new QWidget;
	widget->setLayout(layout = new QGridLayout);
	layout->addWidget(browser = new QTextBrowser, 0, 0, 1, 0);
	layout->addWidget(line = new QLineEdit, 1, 0);
	layout->addWidget(button = new QPushButton(tr("Evaluate")), 1, 1);
	tab->addTab(widget, "GUILE");
	((QDockWidget*)this)->setWidget(tab);
	connect(button, SIGNAL(released()), this, SLOT(doEvaluate()));
	connect(line, SIGNAL(returnPressed()), this, SLOT(doEvaluate()));
}


void ScriptingDock::doEvaluate() {
	std::stringstream stdout, stderr;
	std::string result;
	QString output;
	QString text = line->text();

	line->clear();
	LOG4CXX_INFO(logger, "Evaluating String \"" << text.toStdString() << "\"");
	browser->append(QString("> ") + text);

	interpreter->evaluate(text.toStdString(), stdout, stderr, result);

	output = stdout.str().c_str();
	if (output.endsWith("\n")) output.chop(1);
	if (output != "") browser->append(output);

	output = stderr.str().c_str();
	if (output.endsWith("\n")) output.chop(1);
	if (output != "") browser->append(output);

	browser->append(result.c_str());
}
